@@ -41,33 +41,35 @@ void onlinehelp(int standalone,int context)
     "FN+k Insert row (Press on endmark to",
     "FN+l Delete row change patt. length)",
     "SHIFT+FN+BKSPC Clear/optimize musicdata",
-    "FN+BKSPC Exit program",
+    "FN+BKSPC       ESC/Exit program",
+    "FN+LEFT/RIGHT  HOME/END",
+    "FN+UP/DOWN     PGUP/PGDN",
     NULL
   };
 
   char *patternkeys[] = {
     "Enter notes like on piano (PT or DMC)",
     "0-9 & a-f to enter commands",
-    "SPC Switch between jam/editmode",
+    "SPC  Switch between jam/editmode",
     "BKSPC Insert rest",
     "RET Keyoff (/w SHIFT = Keyon)",
-    "- + Select instrument",
-    "( ) Select octave",
+    "- +  Select instrument",
+    "( )  Select octave",
     "SHIFT+LEFT/RIGHT Select pattern",
     "BACKQUOTE Select channel",
     "SHIFT+SPC Play from cursor pos",
     "SHIFT+UP/DN Mark pattern",
-    "A,S Transpose half down/up",
-    "D,F Transpose octave down/up",
-    "G,B Copy,paste effects",
-    "H Make hifi vib/portaspeed",
+    "A,S  Transpose half down/up",
+    "D,F  Transpose octave down/up",
+    "G,B  Copy,paste effects",
+    "H    Make hifi vib/portaspeed",
     "FN+g Invert selection/pattern",
-    "J,K Join/split pattern",
-    "L Mark/unmark whole pattern",
-    "M,N Choose highlighting step",
-    "./: Shrink/expand pattern",
+    "J,K  Join/split pattern",
+    "L    Mark/unmark whole pattern",
+    "M,N  Choose highlighting step",
+    "./:  Shrink/expand pattern",
     "X,C,V Cut,copy,paste pattern",
-    "Z Cycle autoadvance-mode",
+    "Z    Cycle autoadvance-mode",
     "FN+z,x,c Mute channel",
     NULL
   };
@@ -105,7 +107,7 @@ void onlinehelp(int standalone,int context)
     "G   ""Smart"" instrument paste",
     "H   Unlock/lock table view",
     "X,C,V Cut,copy,paste instr./table",
-    "SHIFT+DEL Delete instrument+tabledata",
+    "SHIFT+BKSPC Delete instrument+tabledata",
     "SHIFT+RET Convert vibrato parameter",
     NULL
   };
@@ -378,12 +380,14 @@ void onlinehelp(int standalone,int context)
         continue;
         break;
 
-    case KEY_ESC:
-      goto EXITHELP;
-      break;
+    case KEY_BACKSPACE:
+      if (fnpressed) {
+        goto EXITHELP;
+        break;
+      }
 
       default:
-      if (rawkey && !standalone) goto EXITHELP;
+      if (rawkey && !standalone && fnpressed) goto EXITHELP;
 
       break;
     }
