@@ -319,15 +319,17 @@ void patterncommands(void)
 //    break;
 
     case KEY_COLON:
-    if (shiftpressed) {
-	expandpattern();
-    } else {
-	shrinkpattern();
+    if (!fnpressed) {
+	if (shiftpressed) {
+	    expandpattern();
+	} else {
+	    shrinkpattern();
+	}
     }
     break;
 
     case KEY_J:
-    if (shiftpressed) joinpattern();
+    if (shiftpressed && !fnpressed) joinpattern();
     break;
 
     case KEY_K:
@@ -368,7 +370,7 @@ void patterncommands(void)
     break;
 
     case KEY_Z:
-    if (shiftpressed)
+    if (shiftpressed && !fnpressed)
     {
       autoadvance++;
       if (autoadvance > 2) autoadvance = 0;
@@ -384,7 +386,7 @@ void patterncommands(void)
     break;
 
     case KEY_G:
-    if (shiftpressed && editmode == EDIT_PATTERN)
+    if (shiftpressed && editmode == EDIT_PATTERN && !fnpressed)
     {
       if (epmarkchn != -1)
       {
@@ -484,7 +486,7 @@ void patterncommands(void)
     break;
 
     case KEY_B:
-    if (shiftpressed && editmode == EDIT_PATTERN)
+    if (shiftpressed && editmode == EDIT_PATTERN && !fnpressed)
     {
       for (c = 0; c < cmdcopyrows; c++)
       {
@@ -497,7 +499,7 @@ void patterncommands(void)
     break;
 
     case KEY_S:
-    if (shiftpressed)
+    if (shiftpressed && !fnpressed)
     {
       if (epmarkchn != -1)
       {
@@ -535,7 +537,7 @@ void patterncommands(void)
     break;
 
     case KEY_A:
-    if (shiftpressed)
+    if (shiftpressed && !fnpressed)
     {
       if (epmarkchn != -1)
       {
@@ -573,7 +575,7 @@ void patterncommands(void)
     break;
 
     case KEY_F:
-    if (shiftpressed)
+    if (shiftpressed && !fnpressed)
     {
       if (epmarkchn != -1)
       {
@@ -623,7 +625,7 @@ void patterncommands(void)
     break;
 
     case KEY_D:
-    if (shiftpressed)
+    if (shiftpressed && !fnpressed)
     {
       if (epmarkchn != -1)
       {
@@ -673,7 +675,7 @@ void patterncommands(void)
     break;
 
     case KEY_M:
-    if (shiftpressed && editmode == EDIT_PATTERN)
+    if (shiftpressed && editmode == EDIT_PATTERN && !fnpressed)
     {
       stepsize++;
       if (stepsize > MAX_PATTROWS) stepsize = MAX_PATTROWS;
@@ -681,7 +683,7 @@ void patterncommands(void)
     break;
 
     case KEY_N:
-    if (shiftpressed && editmode == EDIT_PATTERN)
+    if (shiftpressed && editmode == EDIT_PATTERN && !fnpressed)
     {
       stepsize--;
       if (stepsize < 2) stepsize = 2;
@@ -689,7 +691,7 @@ void patterncommands(void)
     break;
 
     case KEY_H:
-    if (shiftpressed && editmode == EDIT_PATTERN)
+    if (shiftpressed && editmode == EDIT_PATTERN && !fnpressed)
     {
       switch (pattern[epnum[epchn]][eppos*4+2])
       {
@@ -780,7 +782,7 @@ void patterncommands(void)
 
     case KEY_C:
     case KEY_X:
-    if (shiftpressed)
+    if (shiftpressed && !fnpressed)
     {
       if (epmarkchn != -1)
       {
@@ -860,7 +862,7 @@ void patterncommands(void)
     break;
 
     case KEY_V:
-    if ((shiftpressed) && (patterncopyrows))
+    if ((shiftpressed) && (patterncopyrows) && (!fnpressed))
     {
       for (c = 0; c < patterncopyrows; c++)
       {
@@ -899,6 +901,7 @@ void patterncommands(void)
     break;
 
     case KEY_RIGHT:
+    if (!fnpressed) {
     if (!shiftpressed)
     {
       epcolumn++;
@@ -920,8 +923,14 @@ void patterncommands(void)
       if (epchn == epmarkchn) epmarkchn = -1;
     }
     break;
+    } else {
+//END
+        while (eppos != pattlen[epnum[epchn]]) patterndown();
+	break;
+    }
 
     case KEY_LEFT:
+    if (!fnpressed) {
     if (!shiftpressed)
     {
       epcolumn--;
@@ -943,31 +952,30 @@ void patterncommands(void)
       if (epchn == epmarkchn) epmarkchn = -1;
     }
     break;
-
-    case KEY_HOME:
-    while (eppos != 0) patternup();
-    break;
-
-    case KEY_END:
-    while (eppos != pattlen[epnum[epchn]]) patterndown();
-    break;
-
-    case KEY_PGUP:
-    for (scrrep = PGUPDNREPEAT; scrrep; scrrep--)
-      patternup();
-    break;
-
-    case KEY_PGDN:
-    for (scrrep = PGUPDNREPEAT; scrrep; scrrep--)
-      patterndown();
-    break;
+    } else {
+//HOME
+	while (eppos != 0) patternup();
+        break;
+    }
 
     case KEY_UP:
-    patternup();
+    if (fnpressed) {
+//PGUP
+	for (scrrep = PGUPDNREPEAT; scrrep; scrrep--)
+	    patternup();
+    } else {
+        patternup();
+    }
     break;
 
     case KEY_DOWN:
-    patterndown();
+    if (fnpressed) {
+//PGDN
+    for (scrrep = PGUPDNREPEAT; scrrep; scrrep--)
+	patterndown();
+    } else {
+	patterndown();
+    }
     break;
 
     case KEY_APOST2:
